## sh

# 🛠️ **Script Collection**

> [!TIP]  
> Feel free to use and modify these scripts to suit your needs!

---

## 🚀 **Quick Start**

Clone the repository and start using the scripts:

```bash
git clone https://git.k4li.de/scripts/sh.git scripts && cd scripts
```

Or run individual scripts directly:

```bash
curl -fsSL <URL> | sh
```

---

## 📁 **Utility Scripts**

- **🔑 `ssh-keyperm.sh`**  
  Fixes permissions for `.ssh/` keys.

  ```bash
  curl -fsSL https://git.k4li.de/pika/scripts/raw/branch/main/bash/snippets/ssh-keyperm.sh | sh
  ```

- **👽️ `updates.sh`**  
  Updates system packages + flatpaks.

  ```bash
  curl -sSL https://git.k4li.de/pika/scripts/raw/branch/main/bash/setups/updates.sh | sh
  ```

- **🚀 `postinstall.sh`**  
  Sets up basic post-install tasks.

  ```bash
  curl -sSL https://git.k4li.de/pika/scripts/raw/branch/main/bash/setup/postinstall.sh | sh -s -- -- <flag>
  ```

  | **Available Flag** | Description                                                                                                                                                      |
  | ------------------ | ---------------------------------------------------------------------------------------------------------------------------------------------------------------- |
  | --install-base     | Installs base packages like zsh and tmux, zoxide and trash etc.                                                                                                  |
  | --optimize-os      | Currently only supported by apt based systems. Installs nala and fetches best mirrors. Equivalent options might be made in the future for other packagemanagers. |

> [!TIP]
> You can run all options together, with the `all` flag.
>
> ```bash
> curl -sSL https://git.k4li.de/scripts/sh/raw/branch/main/setup/postinstall.sh | sh -s -- --all
> ```

---

## 📦 **Install Scripts**

- **🐋 `docker.sh`**  
  Installs Docker (Debian, Ubuntu, Fedora).

  ```bash
  curl -sSL https://git.k4li.de/scripts/sh/raw/branch/main/installs/docker.sh | sh
  ```

- **✨ `neovim.sh`**  
  Installs Neovim 10.0+ (Debian, Ubuntu, Fedora).

  ```bash
  curl -sSL https://git.k4li.de/scripts/sh/raw/branch/main/installs/neovim.sh | sh
  ```

- **🎨 `neovide.sh`**  
  Installs Neovide with Cargo (includes Cargo setup).

  ```bash
  curl -sSL https://git.k4li.de/scripts/sh/raw/branch/main/installs/neovide.sh | sh
  ```

- **⚡️`xmrig.sh`**  
  Installs xmrig in `$HOME/.bin/xmrig/`.

  ```bash
  curl -sSL https://git.k4li.de/scripts/sh/raw/branch/main/installs/xmrig.sh | sh
  ```

- **🗃️ `yazi.sh`**  
  Installs [yazi](https://github.com/sxyazi/yazi) with Cargo.
  ```bash
  curl -fsSL https://git.k4li.de/scripts/sh/raw/branch/main/installs/yazi.sh | sh
  ```

---

## 📚 **Browse More**

Explore additional scripts in the repository. Modify them or use them as-is to streamline your workflow!

---
